@@ -43,6 +43,8 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 
+#include <games-stock.h>
+
 /*****************************************************************************/
 /* Used widgets. */
 
@@ -76,11 +78,13 @@ static const struct poptOption options[] = {
 };
 
 /****************************************************************************/
-/* The menus */
-static GnomeUIInfo game_menu[];
-static GnomeUIInfo help_menu[];
-static GnomeUIInfo settings_menu[];
-static GnomeUIInfo main_menu[];
+/* The actions */
+static GtkAction *pause_action;
+static GtkAction *end_game_action;
+static GtkAction *restart_level_action;
+static GtkAction *scores_action;
+
+
 
 
 /****************************************************************************/
@@ -119,20 +123,23 @@ load_image_from_path (const char *relative_name)
   if (!image)
     {
       GtkWidget *widget;
-      char       buffer[1024];
-      g_snprintf (buffer, sizeof(buffer), 
-		  _("An error occured while loading the image file \"%s\".\n"
-		    "Please make sure, that GNOME Stones is "
-		    "correctly installed!"), relative_name);
+      char *message;
+      
+      message = g_strdup_printf (_("An error occurred while loading the image file \"%s\".\n"
+                                   "Please make sure that GNOME Stones is "
+		                   "correctly installed!"), relative_name);
 					    
       widget= gtk_message_dialog_new (GTK_WINDOW(app), 
                                       GTK_DIALOG_DESTROY_WITH_PARENT,
                                       GTK_MESSAGE_ERROR, 
                                       GTK_BUTTONS_OK, 
-                                      buffer);
+                                      message);
       gtk_dialog_run(GTK_DIALOG(widget));
 
       gtk_widget_destroy(widget);
+      g_free (message);
+
+      exit(1);
     }
   
   return image;
@@ -184,7 +191,8 @@ title_image_load (void)
   image = load_image_from_path ("gnome-stones/title-tile.png");
   if (image != NULL) 
     {
-      gdk_pixbuf_render_pixmap_and_mask (image, &tile, NULL, 127);
+      gdk_pixbuf_render_pixmap_and_mask_for_colormap (image, gdk_colormap_get_system(),
+						      &tile, NULL, 127);
       gdk_pixbuf_unref (image);
     }
 
@@ -214,62 +222,6 @@ title_image_load (void)
 
 /* Game widget handling.  */
 
-#ifdef USE_GNOME_CANVAS
-static GnomeCanvasItem *game_items[GAME_COLS][GAME_ROWS];
-static GdkPixbuf   *game_current_images[GAME_COLS][GAME_ROWS];
-
-
-static void
-game_update_image (GtkWidget *widget)
-{
-  GdkPixbuf *image;
-  int x1, y1, x2, y2, x, y;
-
-  x1 = x_offset;
-  y1 = y_offset;
-  x2 = GAME_COLS+x_offset-1;
-  y2 = GAME_ROWS+y_offset-1;
-  
-  for (x = x1; x <= x2; x++)
-    for (y = y1; y <= y2; y++)
-      {
-	
-	gboolean cave_mode;
-	
-	if ((curtain_mode == GAME_CURTAIN_CLOSING && 
-	     (x+y > curtain+x_offset+y_offset)) ||
-	    (curtain_mode == GAME_CURTAIN_OPENING && 
-	     (x+y < curtain+x_offset+y_offset)))
-	  {
-	    cave_mode= TRUE;
-	    image= curtain_pixbuf_image;
-	  }
-	else if (display_mode == GAME_DISPLAY_IMAGE)
-	  {
-	    cave_mode= FALSE;
-	  }
-	else
-	  {
-	    cave_mode= TRUE;
-
-	    image= cave_get_pixbuf_image (cave, x+1, y+1);
-	  }
-	
-	if (image != game_current_images[x-x_offset][y-y_offset])
-	  {
-	    gnome_canvas_item_set (game_items[x-x_offset][y-y_offset],
-				   "image", image,
-				   NULL);
-	    game_current_images[x-x_offset][y-y_offset]= image;
-	  }
-      }
-
-  gnome_canvas_update_now (GNOME_CANVAS (widget));
-}
-#endif
-
-
-
 static void
 game_update_title (void)
 {
@@ -286,7 +238,7 @@ game_update_title (void)
       static char *gametitle = N_("Game title");
       static char *cavename = N_("Start cave");
 
-      guint width, height;
+      gint height;
       PangoLayout *layout;
       PangoFontDescription *pfd;
       GList *tmp = g_list_nth (game->start_caves, start_cave);
@@ -295,13 +247,9 @@ game_update_title (void)
       pfd = pango_font_description_from_string ("[sans-serif][bold][16]");
       pango_layout_set_font_description (layout, pfd);
       
-      pango_layout_get_pixel_size (layout, &width, &height);
+      pango_layout_get_pixel_size (layout, NULL, &height);
 
-#ifdef USE_ORIG_TITLE_SCREEN
       gc = gstones_view->style->black_gc;
-#else
-      gc = gstones_view->style->black_gc;
-#endif
 
       gdk_draw_layout (title_image, gc,
                        50, 
@@ -352,7 +300,7 @@ game_widget_key_press_callback (GtkWidget   *widget,
 				gpointer     client_data)
 {
   player_push= event->state & GDK_SHIFT_MASK;
-  
+
   switch (event->keyval)
     {
     case GDK_KP_8:
@@ -456,46 +404,10 @@ game_widget_key_release_callback (GtkWidget   *widget,
       last_keyval       =  GDK_VoidSymbol;
       return TRUE;
     }
-
   return FALSE;
 }
 
 
-#ifdef USE_GNOME_CANVAS
-/* We need this variable to be global, because we can only fill this
-   canvas after loading the needed images.  */
-GtkWidget *canvas;
-
-/* This function need 'canvas' and 'curtain_pixbuf_image' to have well
-   defined values.  */
-
-static gboolean
-game_widget_fill (void)
-{
-  guint x;
-  guint y;
-  
-  for (x= 0; x < GAME_COLS ; x+= 1)
-    for (y= 0; y < GAME_COLS ;  y+= 1)
-      {
-	game_items[x][y]=
-	  gnome_canvas_item_new (GNOME_CANVAS_GROUP (gnome_canvas_root 
-						     (GNOME_CANVAS 
-						      (canvas))),
-				 gnome_canvas_pixbuf_get_type (),
-				 "pixbuf", curtain_pixbuf_image,
-				 "x", (double) x*STONE_SIZE,
-				 "y", (double) y*STONE_SIZE,
-				 "width", (double) , gdk_pixbuf_get_width (curtain_pixbuf_image),
-				 "height", (double) gdk_pixbuf_get_height (curtain_pixbuf_image),
-				 NULL);
-	
-      }
-  
-  return TRUE;
-}
-#endif /* USE_GNOME_CANVAS */
-
 /****************************************************************************/
 /* High score enabling/disabling */
 
@@ -510,12 +422,12 @@ update_score_state (void)
 	top = gnome_score_get_notable (APP_NAME, NULL, &names,
                                        &scores, &scoretimes);
 	if (top > 0) {
-		gtk_widget_set_sensitive (game_menu[6].widget, TRUE);
+		gtk_action_set_sensitive (scores_action, TRUE);
 		g_strfreev(names);
 		g_free(scores);
 		g_free(scoretimes);
 	} else {
-		gtk_widget_set_sensitive (game_menu[6].widget, FALSE);
+		gtk_action_set_sensitive (scores_action, FALSE);
 	}
 }
 
@@ -527,7 +439,7 @@ update_score_state (void)
 
 static guint iteration_timeout= 0;
 static guint countdown_timeout= 0;
-
+static guint delay_timeout = 0;
 /****************************************************************************/
 
 GStonesCave *curtain_cave;
@@ -551,7 +463,9 @@ curtain_ready (ViewCurtainMode mode)
 	     CURTAIN_DISPLAY_NONE;
 
 	  state= STATE_WAITING_TO_START;
-	  g_timeout_add (START_DELAY, start_cave_delay_timeout, curtain_cave);
+	  delay_timeout = g_timeout_add (START_DELAY, 
+					 start_cave_delay_timeout, 
+					 curtain_cave);
 	}
       else
 	{
@@ -633,6 +547,7 @@ start_cave_delay_timeout (gpointer data)
       state= STATE_RUNNING;
     }
 
+  delay_timeout = 0;
   return FALSE;
 }
 
@@ -666,8 +581,11 @@ countdown_timeout_function (gpointer data)
 	  return TRUE;
 	}
       
-      if (cave->next)
+      if (cave->next) {
 	newcave= gstones_cave_load (game, cave->next);
+	start_cave++;
+	gconf_set_start_cave (start_cave);
+      }
 	
       curtain_start (newcave);
 
@@ -826,10 +744,23 @@ iteration_timeout_function (gpointer data)
 {
   GStonesCave *cave  = (GStonesCave *)data;
   gint         retval= TRUE;
+  static gboolean gameplay_iteration = TRUE;
 
   if (state == STATE_TITLE)
     return TRUE;
 
+  /* This gives us one game iteration for every 2 drawing iterations. */
+  if (!gameplay_iteration) {
+    view_calculate_offset (GSTONES_VIEW (gstones_view), cave);
+    gtk_widget_queue_draw_area (gstones_view, 0, 0,
+                                GAME_COLS * STONE_SIZE,
+                                GAME_ROWS * STONE_SIZE);
+    gameplay_iteration = TRUE;
+    return retval;
+  }
+ 
+  gameplay_iteration = FALSE;
+
   joystick_get_information (&player_x_direction, &player_y_direction);
   
   cave_iterate (cave, player_x_direction, player_y_direction, player_push);
@@ -881,14 +812,9 @@ iteration_timeout_function (gpointer data)
 
   /* Manage scrolling.  */
   view_calculate_offset (GSTONES_VIEW (gstones_view), cave);
-
-#ifdef USE_GNOME_CANVAS  
-  game_update_image (gstones_view);
-#else
   gtk_widget_queue_draw_area (gstones_view, 0, 0,
                               GAME_COLS * STONE_SIZE,
                               GAME_ROWS * STONE_SIZE);
-#endif
   flags= cave->flags;
 
   return retval;
@@ -905,8 +831,10 @@ iteration_start (GStonesCave *newcave)
   cave_set_player (cave, player);
   status_set_cave (cave->name);
   
+  /* We set the timeout to half of the frame rate so we will have
+   * 2 graphical cycle for every game cycle. */
   iteration_timeout= 
-    g_timeout_add (game->frame_rate, iteration_timeout_function, cave);
+    g_timeout_add (game->frame_rate / 2, iteration_timeout_function, cave);
 }
 
 
@@ -991,6 +919,10 @@ show_scores_dialog (gint pos)
   if (dialog != NULL) {
     gtk_window_set_transient_for (GTK_WINDOW(dialog), GTK_WINDOW(app));
     gtk_window_set_modal (GTK_WINDOW(dialog), TRUE);
+    gtk_dialog_set_has_separator (GTK_DIALOG(dialog), FALSE);
+    gtk_container_set_border_width (GTK_CONTAINER(dialog), 5);
+    gtk_box_set_spacing (GTK_BOX (GTK_DIALOG(dialog)->vbox), 2);
+    gtk_window_set_resizable (GTK_WINDOW(dialog), FALSE);
   }
 }
 
@@ -1059,6 +991,12 @@ preferences_cb (GtkWidget *widget, gpointer data)
 void
 quit_cb (GtkWidget *widget, gpointer data)
 {
+  if (iteration_timeout) g_source_remove (iteration_timeout);
+  if (countdown_timeout) g_source_remove (countdown_timeout);
+  if (delay_timeout) g_source_remove (delay_timeout);
+  if (GSTONES_VIEW(gstones_view)->curtain_timeout) 
+    g_source_remove (GSTONES_VIEW(gstones_view)->curtain_timeout);
+
   preferences_save_global ();
   sound_close();
 
@@ -1075,54 +1013,31 @@ show_scores_cb (GtkWidget *widget, gpointer data)
 
 static void
 about_cb (GtkWidget *widget, gpointer data)
-{
-  static GtkWidget *about= NULL;
-  GdkPixbuf *pixbuf = NULL;
-  
+{  
   const gchar *authors[]= {
     N_("Main game:"),
-    "Carsten Schaar <nhadcasc@fs-maphy.uni-hannover.de>",
+    "Carsten Schaar",
     "",
     N_("Sokoban levels:"),
     "Herman Mansilla",
     NULL
   };
-  gchar *documenters[] = {
-                          NULL
-                         };
-  /* Translator credits */
-  gchar *translator_credits = _("translator-credits");
 
-  if (about != NULL) {
-    gtk_window_present (GTK_WINDOW(about));
-    return;
-  }
-  {
-	  char *filename = NULL;
+  gtk_show_about_dialog (GTK_WINDOW (app),
+			 "name", _("GNOME Stones"),
+			 "version", VERSION,
+			 "copyright", "Copyright \xc2\xa9 1998-2004 Carsten Schaar",
+			 "comments", _("Mine through dirt and collect gems."),
+			 "authors", authors,
+			 "translator_credits", _("translator-credits"),
+			 NULL);
+}
 
-	  filename = gnome_program_locate_file (NULL,
-			  GNOME_FILE_DOMAIN_APP_PIXMAP,  ("gnome-stones.png"),
-			  TRUE, NULL);
-	  if (filename != NULL)
-	  {
-		  pixbuf = gdk_pixbuf_new_from_file(filename, NULL);
-		  g_free (filename);
-	  }
-  }
-  about= gnome_about_new (_("GNOME Stones"), VERSION,
-			  "Copyright \xc2\xa9 1998-2003 Carsten Schaar",
-			  _("Mine through dirt and collect gems."),
-			  (const char **)authors,
-                          (const char **)documenters,
-                          strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-			  pixbuf);
-  
-  if (pixbuf != NULL)
-		gdk_pixbuf_unref (pixbuf);
-  
-  gtk_window_set_transient_for (GTK_WINDOW (about), GTK_WINDOW (app));
-  g_signal_connect (G_OBJECT (about), "destroy", G_CALLBACK (gtk_widget_destroyed), &about);
-  gtk_widget_show (about);
+
+static void
+help_cb (GtkAction *action, gpointer data)
+{
+  gnome_help_display ("gnome-stones.xml", NULL, NULL); 
 }
 
 
@@ -1131,46 +1046,73 @@ about_cb (GtkWidget *widget, gpointer data)
 /* Menu definitions */
 
 
-static GnomeUIInfo game_menu[]= {
-  GNOMEUIINFO_MENU_NEW_GAME_ITEM(game_start_cb, NULL),
-  GNOMEUIINFO_MENU_END_GAME_ITEM(game_stop_cb, NULL),
-  GNOMEUIINFO_ITEM_STOCK(N_("_Restart level"), N_("Restart the current level"), level_restart_cb, GTK_STOCK_REFRESH),
-  GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_MENU_PAUSE_GAME_ITEM (game_pause_cb, NULL),
-  GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_MENU_SCORES_ITEM(show_scores_cb, NULL),
-  GNOMEUIINFO_SEPARATOR,
-  GNOMEUIINFO_MENU_QUIT_ITEM(quit_cb, NULL),
-  GNOMEUIINFO_END
+static const GtkActionEntry action_entry[] = {
+  { "GameMenu", NULL, N_("_Game") },
+  { "SettingsMenu", NULL, N_("_Settings") },
+  { "HelpMenu", NULL, N_("_Help") },
+  { "NewGame", GAMES_STOCK_NEW_GAME, NULL, NULL, NULL, G_CALLBACK (game_start_cb) },
+  { "EndGame", GAMES_STOCK_END_GAME, NULL, NULL, NULL, G_CALLBACK (game_stop_cb) },
+  { "RestartLevel", GAMES_STOCK_RESTART_GAME, "_Restart Level", NULL, NULL, G_CALLBACK (level_restart_cb) },
+  { "Pause", GAMES_STOCK_PAUSE_GAME, NULL, NULL, NULL, G_CALLBACK (game_pause_cb) },
+  { "Scores", GAMES_STOCK_SCORES, NULL, NULL, NULL, G_CALLBACK (show_scores_cb) },
+  { "Quit", GTK_STOCK_QUIT, NULL, NULL, NULL, G_CALLBACK (quit_cb) },
+  { "Preferences", GTK_STOCK_PREFERENCES, NULL, NULL, NULL, G_CALLBACK (preferences_cb) },
+  { "Contents", GAMES_STOCK_CONTENTS, NULL, NULL, NULL, G_CALLBACK (help_cb) },
+  { "About", GTK_STOCK_ABOUT, NULL, NULL, NULL, G_CALLBACK (about_cb) }
 };
 
-static GnomeUIInfo help_menu[]= {
-  GNOMEUIINFO_HELP(APP_NAME),
-  GNOMEUIINFO_MENU_ABOUT_ITEM(about_cb, NULL),
-  GNOMEUIINFO_END
-};
 
-static GnomeUIInfo settings_menu[]= {
-  GNOMEUIINFO_MENU_PREFERENCES_ITEM(preferences_cb, NULL),
-  GNOMEUIINFO_END
-};
+static const char ui_description[] =
+"<ui>"
+"  <menubar name='MainMenu'>"
+"    <menu action='GameMenu'>"
+"      <menuitem action='NewGame'/>"
+"      <menuitem action='EndGame'/>"
+"      <menuitem action='RestartLevel'/>"
+"      <separator/>"
+"      <menuitem action='Pause'/>"
+"      <separator/>"
+"      <menuitem action='Scores'/>"
+"      <separator/>"
+"      <menuitem action='Quit'/>"
+"    </menu>"
+"    <menu action='SettingsMenu'>"
+"      <menuitem action='Preferences'/>"
+"    </menu>"
+"    <menu action='HelpMenu'>"
+"      <menuitem action='Contents'/>"
+"      <menuitem action='About'/>"
+"    </menu>"
+"  </menubar>"
+"</ui>";
 
-static GnomeUIInfo main_menu[]= 
+
+static void
+create_menus (GtkUIManager *ui_manager)
 {
-  GNOMEUIINFO_MENU_GAME_TREE(game_menu),
-  GNOMEUIINFO_MENU_SETTINGS_TREE(settings_menu),
-  GNOMEUIINFO_MENU_HELP_TREE(help_menu),
-  GNOMEUIINFO_END
-};
+        GtkActionGroup *action_group;
 
+        action_group = gtk_action_group_new ("group");
+
+        gtk_action_group_set_translation_domain(action_group, GETTEXT_PACKAGE);
+        gtk_action_group_add_actions (action_group, action_entry, G_N_ELEMENTS (action_entry), app);
+
+        gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+        gtk_ui_manager_add_ui_from_string (ui_manager, ui_description, -1, NULL);
+
+        scores_action = gtk_action_group_get_action (action_group, "Scores");
+	end_game_action = gtk_action_group_get_action (action_group, "EndGame");
+	restart_level_action = gtk_action_group_get_action (action_group, "RestartLevel");
+	pause_action = gtk_action_group_get_action (action_group, "Pause");
+}
 
 /*****************************************************************************/
 /* Menu sensitivity code. */
 static void menu_set_sensitive (gboolean state)
 {
-  gtk_widget_set_sensitive (game_menu[1].widget, state);
-  gtk_widget_set_sensitive (game_menu[2].widget, state);
-  gtk_widget_set_sensitive (game_menu[4].widget, state);
+  gtk_action_set_sensitive (end_game_action, state);
+  gtk_action_set_sensitive (restart_level_action, state);
+  gtk_action_set_sensitive (pause_action, state);
 }
 
 
@@ -1245,12 +1187,6 @@ StartupSequence startup_sequence[]=
     scan_public_plugin_directory,
     N_("Scanning public object directory...")
   },
-#ifdef USE_GNOME_CANVAS
-  {
-    game_widget_fill,
-    N_("Filling game widget...")
-  },
-#endif /* USE_GNOME_CANVAS */
   {
     scan_private_game_directory,
     N_("Scanning private game directory...")
@@ -1313,7 +1249,10 @@ main (int argc, char *argv[])
   GtkWidget *frame= NULL;
   GtkWidget *vbox = NULL;
   GtkWidget *table= NULL;
-  
+  GtkWidget *menubar;
+  GtkUIManager *ui_manager;  
+  GtkAccelGroup *accel_group;
+
   gnome_score_init (APP_NAME);
 
   bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
@@ -1337,21 +1276,21 @@ main (int argc, char *argv[])
   app = gnome_app_new ("gnome-stones", _("GNOME Stones"));
   gtk_window_set_resizable  (GTK_WINDOW (app), FALSE);
 
-  /* ... a menu line, ... */
-  gnome_app_create_menus (GNOME_APP (app), main_menu);
+  table = status_widget_get ();
+
+  games_stock_init ();
+
+  ui_manager = gtk_ui_manager_new ();
+  create_menus (ui_manager);
+  accel_group = gtk_ui_manager_get_accel_group (ui_manager);
+  gtk_window_add_accel_group (GTK_WINDOW (app), accel_group);
+  menubar = gtk_ui_manager_get_widget (ui_manager, "/MainMenu");
   menu_set_sensitive (FALSE);
-  
-  /* ... a toolbar, ... */
-  /*  gnome_app_create_toolbar (GNOME_APP (app), toolbar); */
 
-  /* ... a statusline ... */
-  statusbar= gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_USER);
+  statusbar = gnome_appbar_new (TRUE, TRUE, GNOME_PREFERENCES_USER);
   gnome_app_set_statusbar (GNOME_APP (app), statusbar);
-
   gnome_appbar_set_default (GNOME_APPBAR (statusbar), _(default_message));
 
-  gnome_app_install_menu_hints(GNOME_APP (app), main_menu);
-
   /* and, last but not least the game display.  */
   vbox = gtk_vbox_new (FALSE, 0);
 
@@ -1362,9 +1301,9 @@ main (int argc, char *argv[])
   gtk_widget_show (frame);
   gtk_container_add (GTK_CONTAINER (frame), gstones_view);
 
+  gtk_box_pack_start (GTK_BOX (vbox), menubar, FALSE, FALSE, 0);
   gtk_box_pack_start (GTK_BOX (vbox), frame, TRUE, TRUE, 0);
 
-  table= status_widget_get ();
   gtk_widget_show (table);
   gtk_box_pack_start (GTK_BOX (vbox), table, TRUE, TRUE, 0);
   
