@@ -57,7 +57,6 @@ int NumberOfRolls;
 int WinningScore;
 int DisplayComputerThoughts = 0;
 int OnlyShowScores = 0;
-int IsCheater;
 int CurrentPlayer;
 char *DefaultPlayerNames[MAX_NUMBER_OF_PLAYERS] = { N_("Human"),
 						    "Wilber",
@@ -79,7 +78,7 @@ char *FieldLabels[NUM_FIELDS+EXTRA_FIELDS] =
         N_("Full House [25]"),
         N_("Small Straight [30]"),
         N_("Large Straight [40]"),
-        N_("Yahtzee [50]"),
+        N_("5 of a Kind [50]"),
         N_("Chance [total]"),
 	/* End of lower panel */
 	N_("Lower Total"),
