@@ -26,7 +26,6 @@
 #include <libgnomeui/gnome-window-icon.h>
 #include <gdk/gdkkeysyms.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-#include <games-clock.h>
 
 #include <sys/time.h>
 #include <string.h>
@@ -43,7 +42,6 @@ GtkWidget *drawing_area;
 GtkWidget *tile_dialog;
 GtkWidget *black_score;
 GtkWidget *white_score;
-GtkWidget *time_display;
 
 GdkPixmap *buffer_pixmap = NULL;
 GdkPixmap *tiles_pixmap = NULL;
@@ -51,8 +49,6 @@ GdkPixmap *tiles_mask = NULL;
 
 gint flip_pixmaps_id = 0;
 gint statusbar_id;
-guint whose_turn = BLACK_TURN;
-guint game_in_progress = 0;
 guint black_computer_level;
 guint white_computer_level;
 guint black_computer_id = 0;
@@ -66,8 +62,6 @@ guint tiles_to_flip = 0;
 gint64 milliseconds_total = 0;
 gint64 milliseconds_current_start = 0;
 
-gint timer_valid = 0;
-
 gint bcount;
 gint wcount;
 
@@ -117,7 +111,7 @@ static const struct poptOption options[] = {
 GnomeUIInfo game_menu[] = {
         GNOMEUIINFO_MENU_NEW_GAME_ITEM(new_game_cb, NULL),
 
-	GNOMEUIINFO_ITEM(N_("New net_work game"), NULL, new_network_game_cb, NULL),
+	GNOMEUIINFO_ITEM(N_("New Net_work Game"), NULL, new_network_game_cb, NULL),
 
 	GNOMEUIINFO_SEPARATOR,
 
@@ -130,83 +124,8 @@ GnomeUIInfo game_menu[] = {
 	GNOMEUIINFO_END
 };
 
-/*
-GnomeUIInfo black_level_radio_list[] = {
-	{ GNOME_APP_UI_ITEM, N_("_Disabled"),
-	  N_("Disable the computer player"),
-	  black_level_cb, 0, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("Level _One"),
-	  N_("Enable the level 1 computer player"),
-	  black_level_cb, (gpointer) 1, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0,
-	  0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("Level _Two"),
-	  N_("Enable the level 2 computer player"),
-	  black_level_cb, (gpointer) 2, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0,
-	  0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("Level Th_ree"),
-	  N_("Enable the level 3 computer player"),
-	  black_level_cb, (gpointer) 3, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0,
-	  0, NULL },
-
-	GNOMEUIINFO_END
-};
-
-GnomeUIInfo white_level_radio_list[] = {
-	{ GNOME_APP_UI_ITEM, N_("_Disabled"),
-	  N_("Disable the computer player"),
-	  white_level_cb, (gpointer) 0, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("Level _One"),
-	  N_("Enable the level 1 computer player"),
-	  white_level_cb, (gpointer) 1, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("Level _Two"),
-	  N_("Enable the level 2 computer player"),
-	  white_level_cb, (gpointer) 2, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
-
-	{ GNOME_APP_UI_ITEM, N_("Level Th_ree"),
-	  N_("Enable the level 3 computer player"),
-	  white_level_cb, (gpointer) 3, NULL, GNOME_APP_PIXMAP_DATA, NULL, 0, 0, NULL },
-	GNOMEUIINFO_END
-};
-
-GnomeUIInfo black_level_menu[] = {
-	GNOMEUIINFO_RADIOLIST(black_level_radio_list),
-	GNOMEUIINFO_END
-};
-
-GnomeUIInfo white_level_menu[] = {
-	GNOMEUIINFO_RADIOLIST(white_level_radio_list),
-	GNOMEUIINFO_END
-};
-
-GnomeUIInfo comp_menu[] = {
-};
-*/
-
-/*
-GnomeUIInfo settings_computer_submenu[] = {
-        GNOMEUIINFO_SUBTREE_HINT(N_("_Dark"),
-				 N_("Configure the dark computer player"),
-				 black_level_menu),
-        GNOMEUIINFO_SUBTREE_HINT(N_("_Light"), 
-				 N_("Configure the light computer player"),
-				 white_level_menu),
-
-	GNOMEUIINFO_SEPARATOR,
-
-	GNOMEUIINFO_TOGGLEITEM(N_("_Quick moves"),
-			       N_("Turn on quick computer moves"),
-			       quick_moves_cb, NULL),
-	GNOMEUIINFO_END
-};
-*/
-
 GnomeUIInfo settings_menu[] = {
-	GNOMEUIINFO_MENU_PREFERENCES_ITEM (properties_cb, NULL),
+        GNOMEUIINFO_MENU_PREFERENCES_ITEM (properties_cb, NULL),
         GNOMEUIINFO_END
 };
 
@@ -231,6 +150,7 @@ static void undo_set_sensitive (gboolean state)
 void
 quit_game_cb (GtkWidget *widget, gpointer data)
 {
+  games_kill_server ();
   gtk_main_quit ();
 }
 
@@ -301,13 +221,6 @@ undo_move_cb (GtkWidget *widget, gpointer data)
 
 	gui_status ();
 
-	if (timer_valid) {
-		games_clock_stop (GAMES_CLOCK (time_display));
-		gtk_widget_set_sensitive (time_display, FALSE);
-		games_clock_set_seconds (GAMES_CLOCK (time_display), 0);
-		timer_valid = 0;
-	}
-
 	tiles_to_flip = 1;
 
 	check_computer_players ();
@@ -325,14 +238,6 @@ black_level_cb (GtkWidget *widget, gpointer data)
 
         black_computer_level = tmp;
 
-        if (game_in_progress) {
-
-                games_clock_stop (GAMES_CLOCK (time_display));
-                gtk_widget_set_sensitive (time_display, FALSE);
-                games_clock_set_seconds (GAMES_CLOCK (time_display), 0);
-                timer_valid = 0;
-        }
-
         check_computer_players ();
 }
 
@@ -348,63 +253,22 @@ white_level_cb (GtkWidget *widget, gpointer data)
 
         white_computer_level = tmp;
 
-        if (game_in_progress) {
-                games_clock_stop (GAMES_CLOCK (time_display));
-                gtk_widget_set_sensitive (time_display, FALSE);
-                games_clock_set_seconds (GAMES_CLOCK (time_display), 0);
-                timer_valid = 0;
-        }
-
         check_computer_players ();
 }
 
 void
 about_cb (GtkWidget *widget, gpointer data)
 {
-	static GtkWidget *about;
-	GdkPixbuf *pixbuf = NULL;
 	const gchar *authors[] = {"Ian Peters", NULL};
-	const gchar *documenters[] = {
-	    			      NULL
-    	};
-    	const gchar *translator_credits = _("translator-credits");
-	
-	if (about != NULL) {
-                gtk_window_present (GTK_WINDOW (about));
-		return;
-	}
 
-	{
-		char *filename = NULL;
-
-		filename = gnome_program_locate_file 
-			(NULL,
-			 GNOME_FILE_DOMAIN_APP_PIXMAP,  ("iagno.png"),
-			 TRUE, NULL);
-		if (filename != NULL)
-		{
-			pixbuf = gdk_pixbuf_new_from_file (filename, NULL);
-			g_free (filename);
-		}
-	}
-
-	about = gnome_about_new (_("Iagno"), VERSION, 
-				 "Copyright \xc2\xa9 1998-2004 Ian Peters",
-				 _("GNOME version of the popular Othello disk "
-				   "flipping game."), 
-				 (const char **)authors, 
-				 (const char **)documenters,
-				 strcmp (translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
-				 pixbuf);
-	
-	if (pixbuf != NULL)
-		gdk_pixbuf_unref (pixbuf);
-				
-	g_signal_connect (G_OBJECT (about), "destroy",
-			  G_CALLBACK (gtk_widget_destroyed), &about);
-	gtk_window_set_transient_for (GTK_WINDOW(about), GTK_WINDOW(window));
-
-	gtk_widget_show (about);
+	gtk_show_about_dialog (GTK_WINDOW (window),
+			       "name", _("Iagno"),
+			       "version", VERSION,
+			       "copyright", "Copyright \xc2\xa9 1998-2004 Ian Peters",
+			       "comments",_("A disk flipping game derived from Reversi."),
+			       "authors", authors, 
+			       "translator_credits", _("translator-credits"),
+			       NULL);
 }
 
 void
@@ -456,6 +320,9 @@ button_press_event (GtkWidget *widget, GdkEventButton *event)
 {
 	guint x, y;
 
+	if (game_in_progress == 0)
+		return TRUE;
+
 	if (!network_allow ())
 		return TRUE;
 	
@@ -554,8 +421,10 @@ load_pixmaps (void)
 		error = NULL;
 	}
 
-	gdk_pixbuf_render_pixmap_and_mask (image, &tiles_pixmap,
-					   &tiles_mask, 127);
+	gdk_pixbuf_render_pixmap_and_mask_for_colormap (image, 
+							gdk_colormap_get_system(),
+							&tiles_pixmap,
+							&tiles_mask, 127);
 
 	gdk_pixbuf_unref (image);
 	g_free (fname);
@@ -688,6 +557,7 @@ init_new_game (void)
 	clear_board ();
 	game_in_progress = 1;
 	move_count = 0;
+	whose_turn = BLACK_TURN;
 
 	undo_set_sensitive (FALSE);
 	
@@ -707,19 +577,6 @@ init_new_game (void)
 	whose_turn = BLACK_TURN;
 	gui_message (_("Dark's move"));
 
-	games_clock_stop (GAMES_CLOCK (time_display));
-	games_clock_set_seconds (GAMES_CLOCK (time_display), 0);
-
-	if (black_computer_level ^ white_computer_level) {
-		if (! black_computer_level)
-			games_clock_start (GAMES_CLOCK (time_display));
-		gtk_widget_set_sensitive (time_display, TRUE);
-		timer_valid = 1;
-	} else {
-		gtk_widget_set_sensitive (time_display, FALSE);
-		timer_valid = 0;
-	}
-
 	check_computer_players ();
 }
 
@@ -737,8 +594,6 @@ create_window (void)
 
 	gnome_app_create_menus (GNOME_APP (window), mainmenu);
 
-	/* gtk_widget_push_colormap (gdk_rgb_get_cmap ()); */
-
 	drawing_area = gtk_drawing_area_new ();
 
 	gtk_widget_pop_colormap ();
@@ -782,13 +637,6 @@ create_window (void)
 	gtk_widget_show (white_score);
 
 	gtk_table_attach (GTK_TABLE (table), white_score, 5, 6, 0, 1, 0, 0, 3, 1);
-
-	time_display = games_clock_new ();
-	gtk_widget_set_sensitive (time_display, FALSE);
-	gtk_widget_show (time_display);
-
-	gtk_table_attach (GTK_TABLE (table), time_display, 7, 8, 0, 1, 0, 0, 3, 1);
-
 	undo_set_sensitive (FALSE);
 
 	gtk_widget_show (table);
@@ -808,7 +656,7 @@ gui_status (void)
 	gtk_label_set_text (GTK_LABEL (black_score), message);
 	sprintf (message, _("%.2d"), wcount);
 	gtk_label_set_text (GTK_LABEL (white_score), message);
-	undo_set_sensitive (move_count > 0);
+	undo_set_sensitive (move_count > 0 && !is_network_running ());
 }
 
 void
@@ -959,6 +807,8 @@ main (int argc, char **argv)
 
 	set_bg_color ();
 
+	init_new_game ();
+
 	gtk_main ();
 
 	return 0;
